//-*-c++-*-
#ifndef _CLUSTERING_H
#define _CLUSTERING_H

#include <list>
#include <string>
#include "SuperGraph.h"

#include "WithParameter.h"

/**
 * \defgroup plugins
 */ 
/*@{*/
///Interface for clustering plug-ins
class Clustering : public WithParameter
{ 
public :
  Clustering (ClusterContext context):superGraph(context.superGraph),pluginProgress(context.pluginProgress),dataSet(context.dataSet){}
  virtual ~Clustering() {}
  virtual bool run() = 0;
  virtual bool check(std::string &) {return true;}
  virtual void reset() {}  

protected:
  SuperGraph *superGraph;
  PluginProgress *pluginProgress;
  DataSet *dataSet;
};
/*@}*/
#endif






